OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "La version {version} est disponible. Cliquez ici pour plus d'informations sur comment mettre à jour.",
    "Updater" : "Mises à jour",
    "For security reasons the built-in ownCloud updater is using additional credentials. To visit the updater page please click the following button." : "Pour des raisons de sécurité, le module de mises à jour intégré à ownCloud utilise des informations d'identification supplémentaires. Pour visiter la page du module de mises à jour, cliquez sur le bouton suivant.",
    "Open updater" : "Ouvrir le système de mise à jour",
    "A new version is available: %s" : "Une nouvelle version est disponible : %s",
    "Checked on %s" : "Vérifié le %s"
},
"nplurals=2; plural=(n > 1);");
